# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ai_assistant_server_connector.models.ai_assistant_reponse_stream_request import AIAssistantReponseStreamRequest  # noqa: E501

class TestAIAssistantReponseStreamRequest(unittest.TestCase):
    """AIAssistantReponseStreamRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AIAssistantReponseStreamRequest:
        """Test AIAssistantReponseStreamRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AIAssistantReponseStreamRequest`
        """
        model = AIAssistantReponseStreamRequest()  # noqa: E501
        if include_optional:
            return AIAssistantReponseStreamRequest(
                assistant_chat_member_id = 56,
                attachments = [
                    ai_assistant_server_connector.models.chat_message_attachment.ChatMessageAttachment(
                        attachment_type = 'IMAGE', 
                        file_id = '', )
                    ],
                chat_id = 56,
                chat_session_id = 56,
                history = [
                    ai_assistant_server_connector.models.chat_history_item.ChatHistoryItem(
                        content = [
                            ai_assistant_server_connector.models.chat_history_chat_content.ChatHistoryChatContent(
                                text = '', 
                                type = '', )
                            ], 
                        role = 'user', )
                    ],
                name_chat = True,
                portal_info = ai_assistant_server_connector.models.portal_info_request.PortalInfoRequest(
                    domain = 'unknown', 
                    language_id = 56, 
                    owner = ai_assistant_server_connector.models.portal_owner_info.PortalOwnerInfo(
                        email = '', 
                        first_name = '', 
                        last_name = '', ), ),
                session_id = '',
                user_prompt = ''
            )
        else:
            return AIAssistantReponseStreamRequest(
                assistant_chat_member_id = 56,
                chat_id = 56,
                chat_session_id = 56,
                history = [
                    ai_assistant_server_connector.models.chat_history_item.ChatHistoryItem(
                        content = [
                            ai_assistant_server_connector.models.chat_history_chat_content.ChatHistoryChatContent(
                                text = '', 
                                type = '', )
                            ], 
                        role = 'user', )
                    ],
                session_id = '',
                user_prompt = '',
        )
        """

    def testAIAssistantReponseStreamRequest(self):
        """Test AIAssistantReponseStreamRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
