# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ai_assistant_server_connector.models.ai_assistant_list_get import AiAssistantListGet  # noqa: E501

class TestAiAssistantListGet(unittest.TestCase):
    """AiAssistantListGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AiAssistantListGet:
        """Test AiAssistantListGet
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AiAssistantListGet`
        """
        model = AiAssistantListGet()  # noqa: E501
        if include_optional:
            return AiAssistantListGet(
                allow_text = True,
                allow_voice = True,
                approved_urls = [
                    ''
                    ],
                avatar_id = '',
                banned_keywords = [
                    ''
                    ],
                conversation_starter = '',
                conversation_style = 'formal',
                created_at = 56,
                deleted_at = 56,
                function = 'support',
                id = 56,
                is_active = True,
                is_available = True,
                is_live = True,
                knowledgebase_state = ai_assistant_server_connector.models.knowledgebase_state.KnowledgebaseState(
                    course_data = null, ),
                last_updated_at = 56,
                name = '',
                prefer_voice = True,
                system_prompt = '',
                system_prompt_support = '',
                system_prompt_tutor = '',
                type = 'portal',
                voice_id = 56
            )
        else:
            return AiAssistantListGet(
                allow_text = True,
                allow_voice = True,
                approved_urls = [
                    ''
                    ],
                banned_keywords = [
                    ''
                    ],
                conversation_style = 'formal',
                created_at = 56,
                function = 'support',
                id = 56,
                is_active = True,
                is_live = True,
                last_updated_at = 56,
                name = '',
                prefer_voice = True,
                type = 'portal',
                voice_id = 56,
        )
        """

    def testAiAssistantListGet(self):
        """Test AiAssistantListGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
