# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ai_assistant_server_connector.models.ai_assistant_goal_create_update import AiAssistantGoalCreateUpdate  # noqa: E501

class TestAiAssistantGoalCreateUpdate(unittest.TestCase):
    """AiAssistantGoalCreateUpdate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AiAssistantGoalCreateUpdate:
        """Test AiAssistantGoalCreateUpdate
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AiAssistantGoalCreateUpdate`
        """
        model = AiAssistantGoalCreateUpdate()  # noqa: E501
        if include_optional:
            return AiAssistantGoalCreateUpdate(
                additional_prompt = '',
                course_ids = [
                    56
                    ],
                engagement = 0.0,
                engagement_opt_out_duration = 0.0,
                engagement_preset_id = 56,
                id = 56,
                is_active = True,
                max_engagement_count = 0.0,
                max_engagement_period = 0.0,
                max_total_engagement_count = 0.0,
                name = '',
                page_url = '',
                primary_course_id = 56
            )
        else:
            return AiAssistantGoalCreateUpdate(
                additional_prompt = '',
                course_ids = [
                    56
                    ],
                is_active = True,
                name = '',
        )
        """

    def testAiAssistantGoalCreateUpdate(self):
        """Test AiAssistantGoalCreateUpdate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
