# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ai_assistant_server_connector.models.response_wrapper_ai_assistant_session_start import ResponseWrapperAIAssistantSessionStart  # noqa: E501

class TestResponseWrapperAIAssistantSessionStart(unittest.TestCase):
    """ResponseWrapperAIAssistantSessionStart unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperAIAssistantSessionStart:
        """Test ResponseWrapperAIAssistantSessionStart
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperAIAssistantSessionStart`
        """
        model = ResponseWrapperAIAssistantSessionStart()  # noqa: E501
        if include_optional:
            return ResponseWrapperAIAssistantSessionStart(
                done = True,
                error = '',
                result = ai_assistant_server_connector.models.ai_assistant_session_start.AIAssistantSessionStart(
                    ai_assistant = ai_assistant_server_connector.models.ai_assistant_get.AiAssistantGet(
                        allow_text = True, 
                        allow_voice = True, 
                        approved_urls = [
                            ''
                            ], 
                        avatar_id = '', 
                        banned_keywords = [
                            ''
                            ], 
                        conversation_starter = '', 
                        conversation_style = 'formal', 
                        created_at = 56, 
                        deleted_at = 56, 
                        function = 'support', 
                        goals = [
                            ai_assistant_server_connector.models.ai_assistant_goal_get.AiAssistantGoalGet(
                                additional_prompt = '', 
                                ai_assistant_id = 56, 
                                course_ids = [
                                    56
                                    ], 
                                created_at = 56, 
                                engagement = 56, 
                                engagement_opt_out_duration = 56, 
                                engagement_preset = ai_assistant_server_connector.models.goal_engagement_preset_get.GoalEngagementPresetGet(
                                    created_at = 56, 
                                    engagement = 56, 
                                    engagement_opt_out_duration = 56, 
                                    id = 56, 
                                    max_engagement_count = 56, 
                                    max_engagement_period = 56, 
                                    max_total_engagement_count = 56, 
                                    name = '', 
                                    order = 56, ), 
                                engagement_preset_id = 56, 
                                id = 56, 
                                interactions_summary = ai_assistant_server_connector.models.goal_interactions_summary.GoalInteractionsSummary(
                                    is_available = True, 
                                    last_engagement_at = 56, 
                                    last_opt_out_at = 56, 
                                    recent_interaction_count = 56, 
                                    total_interaction_count = 56, ), 
                                is_active = True, 
                                is_fullfilled = True, 
                                last_updated_at = 56, 
                                max_engagement_count = 56, 
                                max_engagement_period = 56, 
                                max_total_engagement_count = 56, 
                                name = '', 
                                page_url = '', 
                                primary_course = ai_assistant_server_connector.models.course_public.CoursePublic(
                                    description = '', 
                                    id = 56, 
                                    modules = [
                                        ai_assistant_server_connector.models.course_module_public.CourseModulePublic(
                                            id = 56, 
                                            lessons = [
                                                ai_assistant_server_connector.models.module_lesson_public.ModuleLessonPublic(
                                                    id = 56, 
                                                    title = '', )
                                                ], 
                                            public_description = '', 
                                            short_description = '', 
                                            title = '', )
                                        ], 
                                    payment_type = null, 
                                    title = '', 
                                    url = '', ), 
                                primary_course_id = 56, )
                            ], 
                        id = 56, 
                        is_active = True, 
                        is_available = True, 
                        is_live = True, 
                        knowledgebase_state = ai_assistant_server_connector.models.knowledgebase_state.KnowledgebaseState(
                            course_data = null, ), 
                        last_updated_at = 56, 
                        lexicon_items = [
                            ai_assistant_server_connector.models.ai_assistant_lexicon_item.AiAssistantLexiconItem(
                                ai_assistant_id = 56, 
                                deleted_at = 56, 
                                id = 56, 
                                order = 56, 
                                pronounciation = '', 
                                term = '', )
                            ], 
                        name = '', 
                        prefer_voice = True, 
                        system_prompt = '', 
                        system_prompt_support = '', 
                        system_prompt_tutor = '', 
                        type = 'portal', 
                        voice_id = 56, ), 
                    credentials = ai_assistant_server_connector.models.emphemeral_credentials.EmphemeralCredentials(
                        ephemeral_token = '', ), )
            )
        else:
            return ResponseWrapperAIAssistantSessionStart(
                done = True,
        )
        """

    def testResponseWrapperAIAssistantSessionStart(self):
        """Test ResponseWrapperAIAssistantSessionStart"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
